import React from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { history } from 'stores/configureStore';
import { settingUp, userLogout } from 'stores/actions/userActions';
import handleKeyDown from 'utils/downloadUtils';
import { handlePackageVersion } from 'utils/utils';
import Modals from 'modals';
import Login from 'components/Login';
import App from './App';


class AppContainer extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        logged: PropTypes.bool,
    };
    
    static defaultProps = {
        dispatch: () => { },
        logged: false,
    };
    
    constructor(props) {
        super(props);
        this.state = {
            hasError: false,
        };
        this.resetError = this.resetError.bind(this);
    }
    
    componentDidMount() {
        Modal.setAppElement('body');
        handlePackageVersion();
        document.addEventListener('keydown', handleKeyDown);
        if (navigator.cookieEnabled) {
            this.props.dispatch(settingUp());
        }
    }
    
    componentDidCatch(error, errorInfo) {
        console.error('error ', error);
        console.error('errorInfo ', errorInfo);
        this.setState({ hasError: true });
        this.props.dispatch(userLogout());
    }
    
    componentWillUnmount() {
        document.removeEventListener('keydown', handleKeyDown);
    }
    
    resetError() {
        this.setState({ hasError: false });
    }
    
    render() {
        // todo: implement routing for login
        if (this.props.logged && !this.state.hasError) {
            return (
                <div id="reactRootElement">
                    <App history={history} />
                    <Modals />
                </div>
            );
        }
    
        return (
            <div id="reactRootElement">
                <Login resetError={this.resetError} />
                <Modals />
            </div>
        );
    }
}

const mapStateToProps = state => ({
    logged: state.user ? state.user.logged : false,
});

export default connect(mapStateToProps)(AppContainer);
