import {
    DASHBOARD,
    ADMIN_TABS_NAME,
    ADMIN_TABS_ROUTES,
    SYSTEM_TABS_NAMES,
    SYSTEM_TABS_ROUTES,
    SYSTEM_TAB_BUTTONS,
    LOGGER_TABS_NAME,
    LOGGER_TABS_ROUTES,
    ROUTING_REPORT_TYPE,
    REPORT_PATH,
} from './constants';
import { NAMES_OF_TABS, REPORTS_SIDE_BAR, SYSTEM_PAGE } from './ui-labels';


const WIDGET_KEYS = [
    DASHBOARD.CURRENT_ALARMS_WIDGET,
    DASHBOARD.WIN_STATUS_WIDGET,
    DASHBOARD.CURRENT_SHIFT_WIDGET,
    DASHBOARD.PERSON_ACTIVITY_WIDGET,
];

const ADMINISTRATION_KEYS = [
    ADMIN_TABS_NAME.COMPANIES,
    ADMIN_TABS_NAME.SUPER_ADMIN_USERS,
    ADMIN_TABS_NAME.PROJECTS,
    ADMIN_TABS_NAME.USERS_PROJECT_SCOPE,
    ADMIN_TABS_NAME.TRACKABLE_OBJECTS,
    ADMIN_TABS_NAME.GROUPS,
    ADMIN_TABS_NAME.ZONES,
    ADMIN_TABS_NAME.NOTIFICATIONS,
    ADMIN_TABS_NAME.NODES,
    ADMIN_TABS_NAME.SHIFTS,
];

const SYSTEM_KEYS = [
    SYSTEM_TABS_NAMES.SERVER,
    SYSTEM_TABS_NAMES.ANCHORS,
];

const REPORT_KEYS = [
    ROUTING_REPORT_TYPE.ATTENDANCE,
    ROUTING_REPORT_TYPE.ALARMS,
    ROUTING_REPORT_TYPE.PWS,
    ROUTING_REPORT_TYPE.ZONE_ACTIVITY,
    // ROUTING_REPORT_TYPE.TRAVEL_DISTANCE,
];

export const WIDGETS = WIDGET_KEYS.reduce((resultObject, key) => {
    resultObject[key] = ({
        name: DASHBOARD[key],
        active: true,
        isExpanded: false,
    });
    return resultObject;
}, {});

export const ADMIN_PAGES = ADMINISTRATION_KEYS.reduce((resultObject, key) => {
    resultObject[key] = ({
        name: NAMES_OF_TABS[key],
        systemName: key,
        dataCy: `nav_submenu_admin_${key.toLowerCase()}`,
        path: ADMIN_TABS_ROUTES[key],
    });
    return resultObject;
}, {});

export const SYSTEM_PAGES = SYSTEM_KEYS.reduce((resultObject, key) => {
    resultObject[key] = ({
        name: SYSTEM_PAGE[key],
        systemName: key,
        dataCy: `nav_submenu_system_${key.toLowerCase()}`,
        path: SYSTEM_TABS_ROUTES[key],
    });
    return resultObject;
}, {});

export const SYSTEM_BUTTONS = {
    SITE_MONITOR: {
        label: SYSTEM_PAGE.SITE_MONITOR,
        name: SYSTEM_TAB_BUTTONS.SITE_MONITOR,
        linkIconClass: 'fas fa-link',
        dataCy: 'nav_submenu_system_site_monitor',
        button: true,
    },
};

export const reportIcons = {
    ATTENDANCE: 'far fa-clock',
    ALARMS: 'fas fa-bell',
    PWS: 'fas fa-people-arrows',
    ZONE_ACTIVITY: 'fas fa-vector-square inner-i',
    TRAVEL_DISTANCE: 'fas fa-route',
};

export const REPORT_PAGES = REPORT_KEYS.reduce((resultObject, key) => {
    resultObject[key] = ({
        name: REPORTS_SIDE_BAR[key],
        systemName: key,
        path: REPORT_PATH[key],
        dataCy: `nav_submenu_report_${key.toLowerCase()}`,
        iconClass: reportIcons[key],
    });
    return resultObject;
}, {});

export const LOGGER_PAGE_TABS = {
    LOGS: {
        name: 'Logs',
        systemName: LOGGER_TABS_NAME.LOGS,
        path: LOGGER_TABS_ROUTES.LOGS,
    },
    ACTIVITIES: {
        name: 'Activities',
        systemName: LOGGER_TABS_NAME.ACTIVITIES,
        path: LOGGER_TABS_ROUTES.ACTIVITIES,
    },
    MESSAGE_PROCESSOR: {
        name: 'Message Processor',
        systemName: LOGGER_TABS_NAME.MESSAGE_PROCESSOR,
        path: LOGGER_TABS_ROUTES.MESSAGE_PROCESSOR,
    },
    DEBUG: {
        name: 'Custom Debug',
        systemName: LOGGER_TABS_NAME.DEBUG,
        path: LOGGER_TABS_ROUTES.DEBUG,
    },
    API: {
        name: 'API',
        systemName: LOGGER_TABS_NAME.API,
        path: LOGGER_TABS_ROUTES.API,
    },
    LEVELS: {
        name: 'LEVELS',
        systemName: LOGGER_TABS_NAME.LEVELS,
        path: LOGGER_TABS_ROUTES.LEVELS,
    },
};
