import React from 'react';
import Select from 'react-select';
import PropTypes from 'prop-types';

const SelectComponent = ({
    options, filterOptions, simpleValue, clearable = true, placeholder,
    noResultsText, input: { value, onChange, onBlur }, isDisabled,
    meta: { touched, error },
}) => (
    <React.Fragment>
        <Select
            disabled={isDisabled}
            simpleValue={simpleValue}
            clearable={clearable}
            filterOptions={filterOptions}
            options={options}
            placeholder={placeholder}
            noResultsText={noResultsText}
            className="menu-outer-top"
            onChange={onChange}
            value={value}
            onBlur={() => onBlur(value)}
        />
        {touched && error && <span className="error">{error}</span>}
    </React.Fragment>
);

SelectComponent.propTypes = {
    options: PropTypes.arrayOf(PropTypes.shape({})),
    filterOptions: PropTypes.arrayOf(PropTypes.shape({})),
    simpleValue: PropTypes.bool,
    placeholder: PropTypes.string,
    noResultsText: PropTypes.shape({}),
    clearable: PropTypes.bool,
    isDisabled: PropTypes.bool,
    input: PropTypes.shape({
        value: PropTypes.oneOfType([PropTypes.shape(), PropTypes.number, PropTypes.string]),
        onChange: PropTypes.func,
        onBlur: PropTypes.func,
    }),
    meta: PropTypes.shape({
        warning: PropTypes.string,
        error: PropTypes.string,
    }),
};

SelectComponent.defaultProps = {
    options: [],
    filterOptions: [],
    simpleValue: false,
    placeholder: '',
    noResultsText: { },
    clearable: false,
    isDisabled: false,
    input: {},
    meta: {
        warning: '',
        error: '',
    },
};

export default SelectComponent;
