import Modal from 'react-modal';
import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import 'react-select/dist/react-select.css';
import { makeCopy } from 'utils/simpleUtils';
import { closeTrackableBulkEditModal, openTrackableBulkEditWarningModal } from 'stores/actions';
import { TRACKABLE_BULK_EDIT } from 'common/ui-labels';
import TrackableBulkEditForm from './TrackableBulkEditForm';


class TrackableBulkEditModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape(),
        trackableBulkEdit: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => { },
        style: {},
        trackableBulkEdit: {},
    };
    
    close = () => {
        this.props.dispatch(closeTrackableBulkEditModal());
    };
    
    submit = (trackableValues) => {
        this.props.dispatch(openTrackableBulkEditWarningModal(trackableValues));
    };
    
    render() {
        const { style, trackableBulkEdit } = this.props;
        
        const style2 = makeCopy(style);
        style2.content.width = 750;
        style2.content.top = '50%';
        style2.content.maxHeight = '100%';
        
        return (
            <Modal
                contentLabel="trackableEdit"
                isOpen={trackableBulkEdit.open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                style={style2}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="trackable-edit-update-title">
                        {TRACKABLE_BULK_EDIT.INFO_TITLE}
                    </span>
                    <span className="grey-text">
                        {TRACKABLE_BULK_EDIT.UNDER_TITLE}
                    </span>
                    <TrackableBulkEditForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    trackableBulkEdit: state.modals.trackableModals.trackableBulkEdit,
});

export default connect(mapStateToProps)(TrackableBulkEditModal);
