import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';
import { TABLES, DEFAULT_VALUES, TRACKABLE_BULK_EDIT } from 'common';
import { openTrackableDeleteModal, openTrackableEditModal, openTrackableBulkEditModal } from 'stores/actions';


class TableButtons extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        setFilterItems: PropTypes.func,
        items: PropTypes.arrayOf(PropTypes.shape()),
        selectedItems: PropTypes.arrayOf(PropTypes.shape()),
        searchFields: PropTypes.arrayOf(PropTypes.string),
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {},
        setFilterItems: () => {},
        items: [],
        selectedItems: [],
        searchFields: [],
        intl: {
            formatMessage: () => {
            },
        },
    };
    
    constructor(props) {
        super(props);
        
        this.timeout = null;
    }
    
    handleSelectedItems = () => {
        const params = [];
        const { selectedItems, items } = this.props;
        selectedItems.forEach((item) => {
            const trackable = items.find(tko => tko.uid === item.uid);
        
            if (trackable) {
                params.push({
                    name: trackable.name,
                    uid: trackable.uid,
                });
            }
        });
        
        return params;
    }
    
    openMultiDeleteModal = () => {
        const params = this.handleSelectedItems();
        
        if (params.length > 0) {
            this.props.dispatch(openTrackableDeleteModal(params));
        }
    };
    
    openBulkEditModal = () => {
        const params = this.handleSelectedItems();
    
        if (params.length > 0) {
            this.props.dispatch(openTrackableBulkEditModal(params));
        }
    }
    
    openAddTrackableModal = () => {
        this.props.dispatch(openTrackableEditModal({
            default_height: DEFAULT_VALUES.trackable_default_height,
            buffer_radius: DEFAULT_VALUES.trackable_buffer_radius,
            sensorSpecialCases: {},
        }));
    };
    
    createAddDeleteBtn = () => {
        const disableBulkAction = this.props.selectedItems.length <= 1;
        return (
            <section className="Table">
                <i
                    className="fas fa-trash-alt fa-lg table-action-icon"
                    data-id="trackables-trash-button"
                    onClick={this.openMultiDeleteModal}
                />
                <i
                    data-id="trackables-plus-button table-action-icon"
                    onClick={this.openAddTrackableModal}
                    className="fa fa-plus fa-lg table-action-icon"
                />
                <button
                    className={`unstyled-button ${disableBulkAction ? 'disabled' : ''}`}
                    data-id="trackables-batch-edit-button table-action-icon"
                    onClick={this.openBulkEditModal}
                    disabled={disableBulkAction}
                    title={TRACKABLE_BULK_EDIT.BUTTON_TITLE_FUNC(this.props.intl)}
                >
                    <i className="far fa-list-alt fa-lg table-action-icon" />
                </button>
            </section>
        );
    };
    
    createCustomSearchField = () => (
        <input
            type="text"
            className="form-control input-sm"
            placeholder={TABLES.SEARCH(this.props.intl)}
            onChange={(e) => {
                const { value } = e.target;
                const regex = new RegExp(value, 'i');
                clearTimeout(this.timeout);
                this.timeout = setTimeout(() => {
                    const filteredItems = [...this.props.items.values()]
                        .filter(item => this.props.searchFields.some(field => item[field] && item[field].match(regex)));
                    this.props.setFilterItems(filteredItems, value);
                }, 600);
            }}
        />
    );

    render() {
        return (
            <div className="Table row row-head-box">
                <div className="col-md-8">{this.createAddDeleteBtn()}</div>
                <div className="col-md-4 text-right">{this.createCustomSearchField()}</div>
            </div>
        );
    }
}

export default connect()(injectIntl(TableButtons));
