import { USER_ROLES } from 'common/user-roles';
import { COMPONENTS } from 'common/ui-labels';
import React from 'react';


class UserActions {
    constructor(props) {
        this.intl = props.intl;
        this.tableUser = props.tableUser;
        this.defaultIconClass = 'inner-table-action';
        this.disableIconClass = 'disable-click';
        
        this.showUserInfo = (tableUser) => {
            props.showUserInfo(tableUser);
        };
        this.openEditModal = (tableUser) => {
            props.openEditModal(tableUser);
        };
        this.openDeleteModal = (tableUser) => {
            props.openDeleteModal(tableUser);
        };
    }
    
    get isCompanyAdmin() {
        return this.tableUser.userType === USER_ROLES.COMPANY_ADMIN;
    }
    
    get detailsBtnClassName() {
        return `fa fa-info-circle ${this.defaultIconClass}`;
    }
    
    get editBtnClassName() {
        if (this.isCompanyAdmin) {
            return `fa fa-pencil-alt ${this.disableIconClass}`;
        }
        return `fa fa-pencil-alt ${this.defaultIconClass}`;
    }
    
    get deleteBtnClassName() {
        if (this.isCompanyAdmin) {
            return `fa fa-times ${this.disableIconClass}`;
        }
        return `fa fa-times ${this.defaultIconClass}`;
    }
    
    get html() {
        return (
            <section data-info="actions-section" style={{ whiteSpace: 'nowrap' }}>
                <i
                    data-info="actions-section"
                    data-id="users-project-actions-info"
                    onClick={() => { this.showUserInfo(this.tableUser); }}
                    title={COMPONENTS.SHOW_DETAILS(this.intl)}
                    className={this.detailsBtnClassName}
                    aria-hidden="true"
                />
                <i
                    data-info="actions-section"
                    data-id="users-project-actions-edit"
                    onClick={() => { this.openEditModal(this.tableUser); }}
                    title={COMPONENTS.EDIT(this.intl)}
                    className={this.editBtnClassName}
                    aria-hidden="true"
                />
                <i
                    data-info="actions-section"
                    data-id="users-project-actions-remove"
                    onClick={() => { this.openDeleteModal(this.tableUser); }}
                    title={COMPONENTS.DELETE(this.intl)}
                    className={this.deleteBtnClassName}
                    aria-hidden="true"
                />
            </section>
        );
    }
}

export default function getUserActions(tableUser, showUserInfo, openEditModal, openDeleteModal, intl) {
    const userAction = new UserActions({ tableUser, showUserInfo, openEditModal, openDeleteModal, intl });
    return userAction.html;
}
