import { USER_ROLES } from 'common/user-roles';
import { USERS_TAB } from 'common/ui-labels';
import { userHasRole } from 'utils/utils';
import React, { Fragment } from 'react';


class HtmlOptions {
    constructor(props) {
        this.intl = props.intl;
    }
    
    companyRolesHtmlOptions() {
        return (
            <Fragment>
                {this.allProjectRolesHtmlOptions()}
                <option
                    data-info="actions-section"
                    value={USER_ROLES.COMPANY_ADMIN}
                >
                    {USERS_TAB.USER_ROLES.COMPANY_ADMIN(this.intl)}
                </option>
            </Fragment>
        );
    }
    
    allProjectRolesHtmlOptions() {
        return (
            <Fragment>
                {this.projectOperationAndUserRolesHtmlOptions()}
                <option
                    data-info="actions-section"
                    value={USER_ROLES.PROJECT_SYSTEM_ADMIN}
                >
                    {USERS_TAB.USER_ROLES.PROJECT_SYSTEM_ADMIN(this.intl)}
                </option>
            </Fragment>);
    }
    
    projectOperationAndUserRolesHtmlOptions() {
        return (
            <Fragment>
                <option
                    data-info="actions-section"
                    value={USER_ROLES.PROJECT_USER}
                >
                    {USERS_TAB.USER_ROLES.PROJECT_USER(this.intl)}
                </option>
                <option
                    data-info="actions-section"
                    value={USER_ROLES.PROJECT_OPERATIONAL_ADMIN}
                >
                    {USERS_TAB.USER_ROLES.PROJECT_OPERATIONS_ADMIN(this.intl)}
                </option>
            </Fragment>
        );
    }
}

class UserDefaultOptions extends HtmlOptions {
    constructor(props) {
        super(props);
        
        this.onChangeType = event => props.updateUserType(event);
        this.intl = props.intl;
        this.tableUser = props.tableUser;
    }
    
    get isCompanyAdmin() {
        return this.tableUser.userType === USER_ROLES.COMPANY_ADMIN;
    }
    
    get companyAdminHtml() {
        return (
            <select
                data-info="actions-section"
                className="form-control input-sm"
                value={this.tableUser.userType}
                disabled
            >
                {this.companyRolesHtmlOptions()}
            </select>
        );
    }
    
    get html() {
        return (<Fragment />);
    }
}

class CurrentUserOptions extends UserDefaultOptions {
    get html() {
        if (this.isCompanyAdmin) {
            return this.companyAdminHtml;
        }
        return (
            <select data-info="actions-section" className="form-control input-sm" value={this.tableUser.userType} disabled>
                {this.allProjectRolesHtmlOptions()}
            </select>
        );
    }
}

class ProjectSystemAdminOptions extends UserDefaultOptions {
    get html() {
        if (this.isCompanyAdmin) {
            return this.companyAdminHtml;
        }
        return (
            <select
                data-info="actions-section"
                className="form-control input-sm"
                data-user-uid={this.tableUser.uid}
                onChange={this.onChangeType}
                value={this.tableUser.userType}
            >
                {this.allProjectRolesHtmlOptions()}
            </select>
        );
    }
}

class ProjectOperationalAdminOptions extends UserDefaultOptions {
    optionsForSystemAdminInTable() {
        return (
            <select
                data-info="actions-section"
                className="form-control input-sm"
                data-user-uid={this.tableUser.uid}
                value={this.tableUser.userType}
                disabled
            >
                {this.allProjectRolesHtmlOptions()}
            </select>
        );
    }
    
    optionsForOperationalAdminInTable() {
        return (
            <select
                data-info="actions-section"
                className="form-control input-sm"
                data-user-uid={this.tableUser.uid}
                onChange={this.onChangeType}
                value={this.tableUser.userType}
            >
                {this.projectOperationAndUserRolesHtmlOptions()}
            </select>
        );
    }
    
    get html() {
        if (this.isCompanyAdmin) {
            return this.companyAdminHtml;
        } else if (this.tableUser.userType === USER_ROLES.PROJECT_SYSTEM_ADMIN) {
            return this.optionsForSystemAdminInTable();
        }
        return this.optionsForOperationalAdminInTable();
    }
}

function isLoggedUser(currentUser, tableUser) {
    return currentUser && tableUser && currentUser.email === tableUser.email;
}

function createUserOptions(intl, tableUser, currentUser, updateUserType) {
    const tableOptions = {
        updateUserType,
        intl,
        tableUser,
    };
    
    if (isLoggedUser(currentUser, tableUser)) {
        return new CurrentUserOptions(tableOptions);
    } else if (userHasRole(currentUser.access, USER_ROLES.PROJECT_SYSTEM_ADMIN)) {
        return new ProjectSystemAdminOptions(tableOptions);
    } else if (userHasRole(currentUser.access, USER_ROLES.PROJECT_OPERATIONAL_ADMIN)) {
        return new ProjectOperationalAdminOptions(tableOptions);
    }
    return new UserDefaultOptions(tableOptions);
}

export default function getUserTypeOptions(intl, tableUser, currentUser, updateUserType) {
    const options = createUserOptions(intl, tableUser, currentUser, updateUserType);
    return options.html;
}

