import { setRolesToUser, setUserType } from 'utils/utils';
import { USER_ROLES } from 'common/user-roles';


export default class User {
    constructor(user) {
        this.uid = user.uid;
        this.admin = user.admin;
        this.email = user.email;
        this.first_name = user.first_name;
        this.last_name = user.last_name;
        this.sign_in_count = user.sign_in_count;
        this.isSystemUser = user.isSystemUser;
        this.project = user.project || null;
        this.created_at = user.created_at;
        this.updated_at = user.updated_at;

        // default values by validation schema
        this.user_details = user.user_details || {};
    }
    
    get userType() {
        return setUserType(this);
    }
    
    getProperties() {
        return { ...this };
    }
    
    updateTagRelation(tagRelation) {
        this.project = { priv: tagRelation.priv, uid: tagRelation.project_uid, name: tagRelation.project_name };
    }
    
    removeTagRelation() {
        this.project = null;
    }
    
    belongToProject(project) {
        if (!project) { return true; }
        return this.project && this.project.uid === project.uid;
    }
    
    getFormattedSuperAdminUser() {
        const formattedUser = { ...this };
        formattedUser.name = '';
        if (this.first_name && this.last_name) {
            formattedUser.name = `${this.first_name} ${this.last_name}`;
        } else if (this.first_name) {
            formattedUser.name = this.first_name;
        } else if (this.last_name) {
            formattedUser.name = this.last_name;
        }
        return formattedUser;
    }
    
    getFormattedUser(project) {
        const formattedUser = { ...this };
        if (this.project && this.admin !== USER_ROLES.COMPANY_ADMIN_STATUS) {
            formattedUser.priv = this.project.priv;
            formattedUser.project_uid = this.project.uid;
        }
        
        formattedUser.name = `${this.first_name} ${this.last_name}`;
        formattedUser.project = (project && project.name) || '';
        formattedUser.roles = setRolesToUser(formattedUser);
        formattedUser.phone_number = this.user_details ? this.user_details.phone_number || '' : '';
        formattedUser.userType = setUserType(this);

        if (formattedUser.userType !== USER_ROLES.COMPANY_ADMIN && this.project) {
            formattedUser.userType = setUserType(this);
            formattedUser.project = this.project.name || '';
            formattedUser.project_uid = this.project.uid || '';
        }
    
        return formattedUser;
    }
    
    static getAllUsers = state => Object.values(state.entities.users.byUid);
}
