import _IsEmpty from 'lodash/isEmpty';
import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import User from 'stores/classes/User';
import { USER_ROLES } from 'common/user-roles';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = {
    byUid: {},
};

function makeStateCopy(state) {
    return {
        byUid: { ...state.byUid },
    };
}

const users = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.USERS_SET: {
            const newState = { byUid: {} };
            action.params.forEach((user) => {
                newState.byUid[user.uid] = new User(user);
            });
            return newState;
        }
        case ACTIONS.USERS_CLEAR:
            return { ...initialState };
        case NOTIFY_ACTIONS.PROJECT_USER_ACCESS_UPDATED:
        case ACTIONS.USERS_UPDATE_PROJECT_ACCESS: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                const user = newState.byUid[param.uid];
                if (user) {
                    const user_copy = new User(user.getProperties());
                    user_copy.updateTagRelation(param);
                    newState.byUid[param.uid] = user_copy;
                }
            });
            return newState;
        }
        case NOTIFY_ACTIONS.PROJECT_DELETED:
        case ACTIONS.PROJECTS_DELETE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);

            params.forEach((param) => {
                const { uid: deletedProjectUid } = param;
                const usersArray = Object.values(newState.byUid);
                usersArray.forEach((user) => {
                    if (!_IsEmpty(user.project) && user.project.uid === deletedProjectUid) {
                        const userEntity = newState.byUid[user.uid];
                        userEntity && userEntity.removeTagRelation();
                    }
                });
            });
            return newState;
        }
        case NOTIFY_ACTIONS.USER_DELETED:
        case ACTIONS.USERS_DELETE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                delete newState.byUid[param.uid];
            });
            return newState;
        }
        case NOTIFY_ACTIONS.USER_UPDATED:
        case ACTIONS.USERS_UPDATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                const clonedUser = new User(param);
                const { project } = newState.byUid[param.uid];
                if (project && clonedUser.userType !== USER_ROLES.COMPANY_ADMIN) {
                    clonedUser.updateTagRelation({
                        project_uid: project.uid,
                        priv: project.priv,
                        project_name: project.name,
                    });
                }
                newState.byUid[param.uid] = clonedUser;
            });
            return newState;
        }
        case NOTIFY_ACTIONS.USER_CREATED:
        case ACTIONS.USERS_CREATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.byUid[param.uid] = new User(param);
            });
            return newState;
        }
        default:
            return state;
    }
};

export default users;
