import { all, call, fork, put, select, takeEvery } from 'redux-saga/effects';
import { DEFAULT_VALUES, SAGA_ACTIONS } from 'common/constants';
import { TRACKABLE_BULK_EDIT } from 'common/ui-labels';
import { closeTrackableBulkEditModal, submitTrackableBulkEditModal, openCommonMessageModal } from 'stores/actions/modalActions';
import { formatCreatedTrackable } from 'common/formatters';
import { valueNaN } from 'utils/utils';
import { groupsList, trackablesList, trackableByUid } from '../selectors';
import errorHandler from '../commonSaga';
import { updateTrackable } from './trackableCreateSaga';


function* handleMessageModal(trackablesCount, errors) {
    let message = '';
    let title = '';
    let status = '';
    const updatedTrackables = trackablesCount - errors.length;
    
    if (errors.length > 0) {
        message = TRACKABLE_BULK_EDIT.WARN_MESSAGE(updatedTrackables, trackablesCount);
        title = TRACKABLE_BULK_EDIT.INFO_TITLE;
        status = DEFAULT_VALUES.WARNING_STATUS;
    } else {
        message = TRACKABLE_BULK_EDIT.INFO_MESSAGE(trackablesCount, trackablesCount);
        title = TRACKABLE_BULK_EDIT.INFO_TITLE;
        status = DEFAULT_VALUES.SUCCESS_STATUS;
    }
    yield put(openCommonMessageModal({ title, message, status }));
}

function* editSingleTrackable(values, uid) {
    const groups = yield select(groupsList);
    const trackables = yield select(trackablesList);
    const storeTrackable = yield select(trackableByUid, uid);
    const trackableValues = { ...values, groupList: (storeTrackable.groups || []).map(guid => ({ uid: guid })) };
    trackableValues.trackables_and_groups = (values.trackables_and_groups || []).filter(trackable_group => trackable_group.uid !== uid);

    const trackable = yield call(formatCreatedTrackable, trackableValues, { trackables, groups });
    const interval = trackable.position_update_interval;
    trackable.uid = uid;
    trackable.name = storeTrackable.name;
    trackable.position_update_interval = (interval && valueNaN(interval.value, interval)) || 0;
    trackable.type = (trackable.type && trackable.type.value) ? trackable.type.value : trackable.type;
    trackable.category = trackable.category.value ? trackable.category.value : trackable.category;
    
    return yield call(updateTrackable, trackable);
}

function* bulkEditTrackable(action) {
    try {
        yield put(submitTrackableBulkEditModal(true));
        const trackables_uids = action.params.editedTrackables.map(tko => tko.value);
        const trackablesCount = trackables_uids.length;
        const trackableValues = { ...action.params };
        delete trackableValues.editedTrackables;
        const errors = [];
        
        for (let i = 0; i < trackables_uids.length; i += 1) {
            const result = yield call(editSingleTrackable, trackableValues, trackables_uids[i]);
            if (result.error) {
                errors.push(result.error);
            }
        }
        
        yield put(submitTrackableBulkEditModal(false));
        yield put(closeTrackableBulkEditModal(action.params));
    
        yield call(handleMessageModal, trackablesCount, errors);
    } catch (err) {
        yield put(submitTrackableBulkEditModal(false));
        yield put(closeTrackableBulkEditModal(action.params));
        yield call(errorHandler, err);
    }
}

function* watchBulkEditTrackable() {
    yield takeEvery(SAGA_ACTIONS.SAGA_TRACKABLES_BULK_EDIT, bulkEditTrackable);
}

export default function* trackableBulkEditSaga() {
    return yield all([
        fork(watchBulkEditTrackable),
    ]);
}
