import { all, fork, call, put, takeEvery, select } from 'redux-saga/effects';
import errorHandler from 'stores/sagas/commonSaga';
import { SAGA_ACTIONS } from 'common/constants';
import { formatEditedZone } from 'utils/zoneUtils';
import { closeZoneEditAdminPageModal, closeZoneEditSitePageModal } from 'stores/actions/modalActions/zoneModalActions';
import { groupsMap, trackablesMap, zonePrototypeList } from 'stores/sagas/selectors';
import { editZone } from 'stores/sagas/zone/zoneSagas';


function* editZoneModal(zone) {
    try {
        const trackables = yield select(trackablesMap);
        const groups = yield select(groupsMap);
        const zoneUid = zone.uid;
        const zonesPrototypes = yield select(zonePrototypeList);
        const updatedZone = yield call(formatEditedZone, zone, trackables, groups, zonesPrototypes);
        yield call(editZone, zoneUid, updatedZone);
    } catch (err) {
        yield call(errorHandler, err);
    }
}

function* editSitePageZone(action) {
    try {
        yield call(editZoneModal, action.params);
        yield put(closeZoneEditSitePageModal());
    } catch (err) {
        yield call(errorHandler, err);
    }
}

function* editAdminPageZone(action) {
    try {
        yield call(editZoneModal, action.params);
        yield put(closeZoneEditAdminPageModal());
    } catch (err) {
        yield call(errorHandler, err);
    }
}


function* watchEditSitePageZone() {
    yield takeEvery(SAGA_ACTIONS.SAGA_ZONES_EDIT_SITE_PAGE, editSitePageZone);
}

function* watchEditAdminPageZone() {
    yield takeEvery(SAGA_ACTIONS.SAGA_ZONES_EDIT_ADMIN_PAGE, editAdminPageZone);
}

export default function* zoneEditSaga() {
    return yield all([
        fork(watchEditSitePageZone),
        fork(watchEditAdminPageZone),
    ]);
}
